package cn.iocoder.yudao.module.sale.vo.offer;

import cn.iocoder.yudao.framework.common.pojo.PageParam;
import cn.iocoder.yudao.framework.common.pojo.TimeSlot;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.ToString;
import org.springframework.format.annotation.DateTimeFormat;

import java.util.Date;
import java.util.List;

import static cn.iocoder.yudao.framework.common.util.date.DateUtils.FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND;

@ApiModel("管理后台 - 报价单管理分页 Request VO")
@Data
@EqualsAndHashCode(callSuper = true)
@ToString(callSuper = true)
public class OfferPageReqVO extends PageParam {

    @ApiModelProperty(value = "报价单号")
    private String number;

    @ApiModelProperty(value = "订单id")
    private Long orderId;

    @ApiModelProperty(value = "订单编号")
    private String orderNo;

    @ApiModelProperty(value = "客户id，发货人")
    private Long consignorId;

    @ApiModelProperty(value = "收货人id")
    private Long consigneeId;

    @ApiModelProperty(value = "唛头")
    private String marks;

    @ApiModelProperty(value = "订单类型(可多选)：1 集运服务 2 海外仓")
    private String serviceType;

    @ApiModelProperty(value = "报关类别：我司全代：1，自单代报：2，混合报关：3")
    private Integer customsType;

    @ApiModelProperty(value = "始发地")
    private Long departureId;

    @ApiModelProperty(value = "始发地信息")
    private String departure;

    @ApiModelProperty(value = "目的地")
    private Long objectiveId;

    @ApiModelProperty(value = "目的地信息")
    private String objective;

    @DateTimeFormat(pattern = FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND)
    @ApiModelProperty(value = "开始预计结束时间")
    private Date beginStopTime;

    @DateTimeFormat(pattern = FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND)
    @ApiModelProperty(value = "结束预计结束时间")
    private Date endStopTime;

    @ApiModelProperty(value = "控货")
    private Boolean control;

    @ApiModelProperty(value = "竞争对手")
    private String competitor;

    @ApiModelProperty(value = "重要程度")
    private Integer importance;

    @DateTimeFormat(pattern = FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND)
    @ApiModelProperty(value = "开始价格有效期开始")
    private Date beginStartTime;

    @DateTimeFormat(pattern = FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND)
    @ApiModelProperty(value = "结束价格有效期开始")
    private Date endStartTime;

    @DateTimeFormat(pattern = FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND)
    @ApiModelProperty(value = "开始价格有效期结束")
    private Date beginEndTime;

    @DateTimeFormat(pattern = FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND)
    @ApiModelProperty(value = "结束价格有效期结束")
    private Date endEndTime;

    @ApiModelProperty(value = "交货方式：FOB(离岸价)，CIF(到岸价)，CNF(成本加运费)，EXW(出厂价)")
    private Integer tradeType;

    @ApiModelProperty(value = "交货港口、地点")
    private String tradeAdress;

    @ApiModelProperty(value = "备注")
    private String remarks;

    @ApiModelProperty(value = "状态：取消报价：0，特价审批中：1，草稿：2 需求确认：3，赢单：4，输单：5，报价完成：6，跟进中: 7")
    private Integer status;

    @ApiModelProperty(value = "取消报价前状态")
    private Integer oldStatus;

    @ApiModelProperty(value = "报价关联客户，发货人：1，收货人：2")
    private Integer relation;

    @ApiModelProperty(value = "报价关联客户id")
    private Long relationId;

    @ApiModelProperty(value = "客户经理ID")
    private Long salesmanId;

    @ApiModelProperty(value = "客户经理所属部门ID")
    private Long deptId;

    @ApiModelProperty(value = "操作用户的所属权限部门ID列表")
    private List<Long> deptIdList;

    @ApiModelProperty(value = "佣金类型：0 无 1 明佣 2 暗佣 3 明+暗")
    private Integer commissionType;

    @ApiModelProperty(value = "入仓类型类型")
    private Integer warehousingType;

    @ApiModelProperty(value = "预计费用清单")
    private String estCost;

    @ApiModelProperty(value = "站内信状态，0未发送，1已发送")
    private Boolean sendstatus;

    @DateTimeFormat(pattern = FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND)
    @ApiModelProperty(value = "开始创建时间")
    private Date beginCreateTime;

    @DateTimeFormat(pattern = FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND)
    @ApiModelProperty(value = "结束创建时间")
    private Date endCreateTime;

    @ApiModelProperty(value = "运输id")
    private Integer transportId;

    @ApiModelProperty(value = "线路id")
    private Long lineId;

    @ApiModelProperty(value = "渠道id")
    private Long channelId;

    @ApiModelProperty(value = "客户经理(跟进业务员)")
    private String followUpSalesmanId;


    @ApiModelProperty(value = "搜索编号(报价单号、订单编号)")
    private String searchNumber;

    @ApiModelProperty(value = "搜索客户(客户名称、客户手机号)")
    private String searchCustomer;

    @ApiModelProperty(value = "商品名称")
    private String prodTitle;

    @ApiModelProperty(value = "创建者或业务员")
    private String creator;


    @ApiModelProperty(value = "客户id")
    private Long customerId;

    @ApiModelProperty(value = "目的国id集合")
    private List<Long> destCountryIds;

    @ApiModelProperty(value = "目的地id集合")
    private List<Long> objectiveIds;

    @ApiModelProperty(value = "目的仓ID集合")
    private List<Long> startWarehouseIds;

    @ApiModelProperty(value = "目的仓ID集合")
    private List<Long> destWarehouseIds;

    @ApiModelProperty(value = "有效期")
    private TimeSlot expired;

    @ApiModelProperty(value = "重要程度")
    private List<Integer> importances;

    @ApiModelProperty(value = "客户经理列表")
    private List<Long> salesmanIds;

    @ApiModelProperty(value = "创建人列表")
    private List<Long> creatorIds;

    @ApiModelProperty(value = "阶段列表")
    private List<Integer> statusList;

    @ApiModelProperty(value = "出货渠道列表")
    private List<Long> channelIds;

    @ApiModelProperty(value = "客户来源列表")
    private List<Long> sourceIds;

}
